gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r20274 - in gnunet/src: dv include namestore


From: gnunet
Subject: [GNUnet-SVN] r20274 - in gnunet/src: dv include namestore
Date: Mon, 5 Mar 2012 13:24:58 +0100

Author: wachs
Date: 2012-03-05 13:24:58 +0100 (Mon, 05 Mar 2012)
New Revision: 20274

Modified:
   gnunet/src/dv/plugin_transport_dv.c
   gnunet/src/include/gnunet_gns_service.h
   gnunet/src/include/gnunet_namestore_service.h
   gnunet/src/namestore/gnunet-service-namestore.c
   gnunet/src/namestore/namestore.h
   gnunet/src/namestore/namestore_common.c
Log:
- doxygen


Modified: gnunet/src/dv/plugin_transport_dv.c
===================================================================
--- gnunet/src/dv/plugin_transport_dv.c 2012-03-05 12:16:39 UTC (rev 20273)
+++ gnunet/src/dv/plugin_transport_dv.c 2012-03-05 12:24:58 UTC (rev 20274)
@@ -385,9 +385,7 @@
  * notify us by calling the env->session_end function
  *
  * @param cls the plugin
- * @param target the neighbour id
- * @param addr pointer to the address
- * @param addrlen length of addr
+ * @param address the address
  * @return the session if the address is valid, NULL otherwise
  */
 static struct Session * 

Modified: gnunet/src/include/gnunet_gns_service.h
===================================================================
--- gnunet/src/include/gnunet_gns_service.h     2012-03-05 12:16:39 UTC (rev 
20273)
+++ gnunet/src/include/gnunet_gns_service.h     2012-03-05 12:24:58 UTC (rev 
20274)
@@ -121,8 +121,6 @@
  * @param handle handle to the GNS service
  * @param timeout how long to wait for transmission of this request to the 
service
  * // FIXME: what happens afterwards?
- * @param handle handle to the GNS service
- * @param timeout timeout of request
  * @param name the name to look up
  * @param type the GNUNET_GNS_RecordType to look for
  * @param iter function to call on each result

Modified: gnunet/src/include/gnunet_namestore_service.h
===================================================================
--- gnunet/src/include/gnunet_namestore_service.h       2012-03-05 12:16:39 UTC 
(rev 20273)
+++ gnunet/src/include/gnunet_namestore_service.h       2012-03-05 12:24:58 UTC 
(rev 20274)
@@ -111,7 +111,7 @@
  *
  * @param cls closure
  * @param success GNUNET_SYSERR on failure (including timeout/queue 
drop/failure to validate)
- *                GNUNET_NO if content was already there
+ *                GNUNET_NO if content was already there or not found
  *                GNUNET_YES (or other positive value) on success
  * @param emsg NULL on success, otherwise an error message
  */
@@ -419,7 +419,7 @@
 /**
  * Serialize the given records to the given destination buffer.
  *
- * @param rd_cound number of records in the rd array
+ * @param rd_count number of records in the rd array
  * @param rd array of GNUNET_NAMESTORE_RecordData with rd_count elements
  * @param dest_size size of the destination array
  * @param dest where to write the result
@@ -438,7 +438,7 @@
  *
  * @param len size of the serialized record data
  * @param src the serialized record data
- * @param rd_cound number of records in the rd array
+ * @param rd_count number of records in the rd array
  * @param dest where to put the data
  *
  * @return GNUNET_OK on success, GNUNET_SYSERR on error

Modified: gnunet/src/namestore/gnunet-service-namestore.c
===================================================================
--- gnunet/src/namestore/gnunet-service-namestore.c     2012-03-05 12:16:39 UTC 
(rev 20273)
+++ gnunet/src/namestore/gnunet-service-namestore.c     2012-03-05 12:24:58 UTC 
(rev 20274)
@@ -225,6 +225,7 @@
  *
  * @param cls closure
  * @param client identification of the client
+ * @param message the stop message
  */
 static void handle_stop (void *cls,
                           struct GNUNET_SERVER_Client * client,

Modified: gnunet/src/namestore/namestore.h
===================================================================
--- gnunet/src/namestore/namestore.h    2012-03-05 12:16:39 UTC (rev 20273)
+++ gnunet/src/namestore/namestore.h    2012-03-05 12:24:58 UTC (rev 20274)
@@ -45,7 +45,16 @@
 
 #define GNUNET_MESSAGE_TYPE_NAMESTORE_DISCONNECT 443
 
-
+/**
+ * Sign name and records
+ *
+ * @param key the private key
+ * @param name the name
+ * @param rd record data
+ * @param rd_count number of records
+ *
+ * @return the signature
+ */
 struct GNUNET_CRYPTO_RsaSignature *
 GNUNET_NAMESTORE_create_signature (const struct GNUNET_CRYPTO_RsaPrivateKey 
*key, const char *name, struct GNUNET_NAMESTORE_RecordData *rd, unsigned int 
rd_count);
 

Modified: gnunet/src/namestore/namestore_common.c
===================================================================
--- gnunet/src/namestore/namestore_common.c     2012-03-05 12:16:39 UTC (rev 
20273)
+++ gnunet/src/namestore/namestore_common.c     2012-03-05 12:24:58 UTC (rev 
20274)
@@ -95,7 +95,7 @@
 /**
  * Serialize the given records to the given destination buffer.
  *
  * @param rd_cound number of records in the rd array
  * @param rd array of GNUNET_NAMESTORE_RecordData with rd_count elements
  * @param dest_size size of the destination array
  * @param dest where to write the result
@@ -158,7 +158,7 @@
  *
  * @param len size of the serialized record data
  * @param src the serialized record data
  * @param rd_cound number of records in the rd array
  * @param dest where to put the data
  *
  * @return GNUNET_OK on success, GNUNET_SYSERR on error
@@ -193,8 +193,21 @@
   return GNUNET_OK; 
 }
 
+/**
+ * Sign name and records
+ *
+ * @param key the private key
+ * @param name the name
+ * @param rd record data
+ * @param rd_count number of records
+ *
+ * @return the signature
+ */
 struct GNUNET_CRYPTO_RsaSignature *
-GNUNET_NAMESTORE_create_signature (const struct GNUNET_CRYPTO_RsaPrivateKey 
*key, const char *name, struct GNUNET_NAMESTORE_RecordData *rd, unsigned int 
rd_count)
+GNUNET_NAMESTORE_create_signature (const struct GNUNET_CRYPTO_RsaPrivateKey 
*key,
+    const char *name,
+    struct GNUNET_NAMESTORE_RecordData *rd,
+    unsigned int rd_count)
 {
   struct GNUNET_CRYPTO_RsaSignature *sig = GNUNET_malloc(sizeof (struct 
@@ -95,7 +95,7 @@
  * Serialize the given records to the given destination buffer.
  *
- * @param rd_cound number of records in the rd array
+ * @param rd_count number of records in the rd array
  * @param rd array of GNUNET_NAMESTORE_RecordData with rd_count elements
  * @param dest_size size of the destination array
@@ -158,7 +158,7 @@
  * @param len size of the serialized record data
  * @param src the serialized record data
- * @param rd_cound number of records in the rd array
+ * @param rd_count number of records in the rd array
  * @param dest where to put the data
  *
GNUNET_CRYPTO_RsaSignature));
   struct GNUNET_CRYPTO_RsaSignaturePurpose *sig_purpose;




reply via email to

[Prev in Thread] Current Thread [Next in Thread]